==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/sagemaker/kotlin/inputs/UserProfileUserSettingsCanvasAppSettingsDirectDeploySettingsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.sagemaker.kotlin.inputs

import com.pulumi.aws.sagemaker.inputs.UserProfileUserSettingsCanvasAppSettingsDirectDeploySettingsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property status Describes whether model deployment permissions are enabled or disabled in the Canvas application. Valid values are `ENABLED` and `DISABLED`.
 */
public data class UserProfileUserSettingsCanvasAppSettingsDirectDeploySettingsArgs(
    public val status: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.sagemaker.inputs.UserProfileUserSettingsCanvasAppSettingsDirectDeploySettingsArgs> {
    override fun toJava():
        com.pulumi.aws.sagemaker.inputs.UserProfileUserSettingsCanvasAppSettingsDirectDeploySettingsArgs =
        com.pulumi.aws.sagemaker.inputs.UserProfileUserSettingsCanvasAppSettingsDirectDeploySettingsArgs.builder()
            .status(status?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [UserProfileUserSettingsCanvasAppSettingsDirectDeploySettingsArgs].
 */
@PulumiTagMarker
public class UserProfileUserSettingsCanvasAppSettingsDirectDeploySettingsArgsBuilder internal
constructor() {
    private var status: Output<String>? = null

    /**
     * @param value Describes whether model deployment permissions are enabled or disabled in the Canvas application. Valid values are `ENABLED` and `DISABLED`.
     */
    @JvmName("nknontmdgdrelmdm")
    public suspend fun status(`value`: Output<String>) {
        this.status = value
    }

    /**
     * @param value Describes whether model deployment permissions are enabled or disabled in the Canvas application. Valid values are `ENABLED` and `DISABLED`.
     */
    @JvmName("ytsrwqvsmgjyljqm")
    public suspend fun status(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.status = mapped
    }

    internal fun build(): UserProfileUserSettingsCanvasAppSettingsDirectDeploySettingsArgs =
        UserProfileUserSettingsCanvasAppSettingsDirectDeploySettingsArgs(
            status = status,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/sagemaker/kotlin/inputs/UserProfileUserSettingsCanvasAppSettingsDirectDeploySettingsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.sagemaker.kotlin.inputs

import com.pulumi.aws.sagemaker.inputs.UserProfileUserSettingsCanvasAppSettingsDirectDeploySettingsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property status Describes whether model deployment permissions are enabled or disabled in the Canvas application. Valid values are `ENABLED` and `DISABLED`.
 */
public data class UserProfileUserSettingsCanvasAppSettingsDirectDeploySettingsArgs(
    public val status: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.sagemaker.inputs.UserProfileUserSettingsCanvasAppSettingsDirectDeploySettingsArgs> {
    override fun toJava(): com.pulumi.aws.sagemaker.inputs.UserProfileUserSettingsCanvasAppSettingsDirectDeploySettingsArgs =
        com.pulumi.aws.sagemaker.inputs.UserProfileUserSettingsCanvasAppSettingsDirectDeploySettingsArgs.builder()
            .status(status?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [UserProfileUserSettingsCanvasAppSettingsDirectDeploySettingsArgs].
 */
@PulumiTagMarker
public class UserProfileUserSettingsCanvasAppSettingsDirectDeploySettingsArgsBuilder internal constructor() {
    private var status: Output<String>? = null

    /**
     * @param value Describes whether model deployment permissions are enabled or disabled in the Canvas application. Valid values are `ENABLED` and `DISABLED`.
     */
    @JvmName("vosjamxuumfklrwa")
    public suspend fun status(`value`: Output<String>) {
        this.status = value
    }

    /**
     * @param value Describes whether model deployment permissions are enabled or disabled in the Canvas application. Valid values are `ENABLED` and `DISABLED`.
     */
    @JvmName("lqkmogmwhuulvqwa")
    public suspend fun status(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.status = mapped
    }

    internal fun build(): UserProfileUserSettingsCanvasAppSettingsDirectDeploySettingsArgs =
        UserProfileUserSettingsCanvasAppSettingsDirectDeploySettingsArgs(
            status = status,
        )
}
